@@ -36,6 +36,13 @@ discrete time intervals, and stochastic or Gillespie :term:`continuous
 time` simulations which are better for handling a wider range of
 :term:`event` probabilities (but which are slightly harder to
 specify).
+
+`epydemic` also provides processes not directly connected with epidemic modelling
+but which are often used alongside disease models. This includes
+support for add/delete networks and percolation processes, as well as
+support for studying the percolation transition in networks. Individual
+network processes can be combined in different ways to encourage good
+software engineering practices.
 '''
 
 # helper types
@@ -73,6 +80,10 @@ from .sis_model_fixed_recovery import SIS_FixedRecovery
 from .adddelete import AddDelete
 from .percolate import Percolate
 from .monitor import Monitor
+from .statistics import NetworkStatistics
+
+# process combinators
+from .processsequence import ProcessSequence
 
 # other experiments
 from .newmanziff import BondPercolation, SitePercolation
