@@ -17,7 +17,10 @@
 # You should have received a copy of the GNU General Public License
 # along with epydemic. If not, see <http://www.gnu.org/licenses/gpl.html>.
 
+from epydemic import Element
 import random
+from networkx import Graph
+from typing import Any, Set
 
 class Locus(object):
     '''The locus of dynamics, where changes can happen. Loci
@@ -29,30 +32,30 @@ class Locus(object):
 
     :param name: the locus name'''
 
-    def __init__( self, name ):
+    def __init__(self, name : str):
         super(Locus, self).__init__()
-        self._name = name
-        self._elements = set()
+        self._name : str = name
+        self._elements : Set[Element] = set()
 
-    def name( self ):
+    def name( self ) -> str:
         '''Returns the name of the locus.
 
         :returns: the locus' name'''
         return self._name
 
-    def __len__( self ):
+    def __len__( self ) -> int:
         '''Return the number of elements at the locus.
 
         :returns: the number of elements'''
         return len(self.elements())
 
-    def elements( self ):
+    def elements( self ) -> Set[Any]:
         '''Return the underlying elements of the locus.
 
         :returns: the elements'''
         return self._elements
     
-    def draw(self):
+    def draw(self) -> Element:
         '''Draw a random element from the locus. The default performs a simple
         draw that is equiprobable across all the elements. The locus remains unchanged:
         drawing simply selects and returns an element at random.
@@ -66,7 +69,7 @@ class Locus(object):
 
     # ---------- Handlers ----------
 
-    def addHandler(self, g, e):
+    def addHandler(self, g : Graph, e : Element):
         '''Handler called when an element is added to the network. This is used to indicate
         the the population of nodes or edges has changed.
 
@@ -74,7 +77,7 @@ class Locus(object):
         :param e: the element'''
         self._elements.add(e)
 
-    def leaveHandler( self, g, e ):
+    def leaveHandler(self, g : Graph, e : Element):
         '''Handler for when an element leaves the locus due to changes in circumstances,
         not changes in population.
 
@@ -82,7 +85,7 @@ class Locus(object):
         :param e: the element'''
         self._elements.discard(e)
 
-    def enterHandler( self, g, e ):
+    def enterHandler(self, g : Graph, e : Element):
         '''Handler for when an element enters the locus due to changes in circumstances,
         not changes in population. 
 
@@ -90,7 +93,7 @@ class Locus(object):
         :param e: the element'''
         self._elements.add(e)
 
-    def removeHandler(self, g, e):
+    def removeHandler(self, g : Graph, e : Element):
         '''Handler called when an element is removed from the network.  This is used to indicate
         the the population of nodes or edges has changed.
 
